@@ -6,9 +6,9 @@ Type annotations for codeguru-reviewer service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codeguru_reviewer.type_defs import AssociateRepositoryRequestTypeDef
+    from mypy_boto3_codeguru_reviewer.type_defs import AssociateRepositoryRequestRequestTypeDef
 
-    data: AssociateRepositoryRequestTypeDef = {...}
+    data: AssociateRepositoryRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -34,8 +34,8 @@ else:
 
 
 __all__ = (
-    "AssociateRepositoryRequestTypeDef",
-    "AssociateRepositoryResponseResponseTypeDef",
+    "AssociateRepositoryRequestRequestTypeDef",
+    "AssociateRepositoryResponseTypeDef",
     "BranchDiffSourceCodeTypeTypeDef",
     "CodeArtifactsTypeDef",
     "CodeCommitRepositoryTypeDef",
@@ -43,32 +43,32 @@ __all__ = (
     "CodeReviewTypeDef",
     "CodeReviewTypeTypeDef",
     "CommitDiffSourceCodeTypeTypeDef",
-    "CreateCodeReviewRequestTypeDef",
-    "CreateCodeReviewResponseResponseTypeDef",
-    "DescribeCodeReviewRequestTypeDef",
-    "DescribeCodeReviewResponseResponseTypeDef",
-    "DescribeRecommendationFeedbackRequestTypeDef",
-    "DescribeRecommendationFeedbackResponseResponseTypeDef",
-    "DescribeRepositoryAssociationRequestTypeDef",
-    "DescribeRepositoryAssociationResponseResponseTypeDef",
-    "DisassociateRepositoryRequestTypeDef",
-    "DisassociateRepositoryResponseResponseTypeDef",
+    "CreateCodeReviewRequestRequestTypeDef",
+    "CreateCodeReviewResponseTypeDef",
+    "DescribeCodeReviewRequestRequestTypeDef",
+    "DescribeCodeReviewResponseTypeDef",
+    "DescribeRecommendationFeedbackRequestRequestTypeDef",
+    "DescribeRecommendationFeedbackResponseTypeDef",
+    "DescribeRepositoryAssociationRequestRequestTypeDef",
+    "DescribeRepositoryAssociationResponseTypeDef",
+    "DisassociateRepositoryRequestRequestTypeDef",
+    "DisassociateRepositoryResponseTypeDef",
     "EventInfoTypeDef",
     "KMSKeyDetailsTypeDef",
-    "ListCodeReviewsRequestTypeDef",
-    "ListCodeReviewsResponseResponseTypeDef",
-    "ListRecommendationFeedbackRequestTypeDef",
-    "ListRecommendationFeedbackResponseResponseTypeDef",
-    "ListRecommendationsRequestTypeDef",
-    "ListRecommendationsResponseResponseTypeDef",
-    "ListRepositoryAssociationsRequestTypeDef",
-    "ListRepositoryAssociationsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "ListCodeReviewsRequestRequestTypeDef",
+    "ListCodeReviewsResponseTypeDef",
+    "ListRecommendationFeedbackRequestRequestTypeDef",
+    "ListRecommendationFeedbackResponseTypeDef",
+    "ListRecommendationsRequestRequestTypeDef",
+    "ListRecommendationsResponseTypeDef",
+    "ListRepositoryAssociationsRequestRequestTypeDef",
+    "ListRepositoryAssociationsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "MetricsSummaryTypeDef",
     "MetricsTypeDef",
     "PaginatorConfigTypeDef",
-    "PutRecommendationFeedbackRequestTypeDef",
+    "PutRecommendationFeedbackRequestRequestTypeDef",
     "RecommendationFeedbackSummaryTypeDef",
     "RecommendationFeedbackTypeDef",
     "RecommendationSummaryTypeDef",
@@ -83,20 +83,20 @@ __all__ = (
     "S3RepositoryDetailsTypeDef",
     "S3RepositoryTypeDef",
     "SourceCodeTypeTypeDef",
-    "TagResourceRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "ThirdPartySourceRepositoryTypeDef",
-    "UntagResourceRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "WaiterConfigTypeDef",
 )
 
-_RequiredAssociateRepositoryRequestTypeDef = TypedDict(
-    "_RequiredAssociateRepositoryRequestTypeDef",
+_RequiredAssociateRepositoryRequestRequestTypeDef = TypedDict(
+    "_RequiredAssociateRepositoryRequestRequestTypeDef",
     {
         "Repository": "RepositoryTypeDef",
     },
 )
-_OptionalAssociateRepositoryRequestTypeDef = TypedDict(
-    "_OptionalAssociateRepositoryRequestTypeDef",
+_OptionalAssociateRepositoryRequestRequestTypeDef = TypedDict(
+    "_OptionalAssociateRepositoryRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
         "Tags": Dict[str, str],
@@ -106,14 +106,15 @@ _OptionalAssociateRepositoryRequestTypeDef = TypedDict(
 )
 
 
-class AssociateRepositoryRequestTypeDef(
-    _RequiredAssociateRepositoryRequestTypeDef, _OptionalAssociateRepositoryRequestTypeDef
+class AssociateRepositoryRequestRequestTypeDef(
+    _RequiredAssociateRepositoryRequestRequestTypeDef,
+    _OptionalAssociateRepositoryRequestRequestTypeDef,
 ):
     pass
 
 
-AssociateRepositoryResponseResponseTypeDef = TypedDict(
-    "AssociateRepositoryResponseResponseTypeDef",
+AssociateRepositoryResponseTypeDef = TypedDict(
+    "AssociateRepositoryResponseTypeDef",
     {
         "RepositoryAssociation": "RepositoryAssociationTypeDef",
         "Tags": Dict[str, str],
@@ -225,16 +226,16 @@ CommitDiffSourceCodeTypeTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCreateCodeReviewRequestTypeDef = TypedDict(
-    "_RequiredCreateCodeReviewRequestTypeDef",
+_RequiredCreateCodeReviewRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateCodeReviewRequestRequestTypeDef",
     {
         "Name": str,
         "RepositoryAssociationArn": str,
         "Type": "CodeReviewTypeTypeDef",
     },
 )
-_OptionalCreateCodeReviewRequestTypeDef = TypedDict(
-    "_OptionalCreateCodeReviewRequestTypeDef",
+_OptionalCreateCodeReviewRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateCodeReviewRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
     },
@@ -242,44 +243,44 @@ _OptionalCreateCodeReviewRequestTypeDef = TypedDict(
 )
 
 
-class CreateCodeReviewRequestTypeDef(
-    _RequiredCreateCodeReviewRequestTypeDef, _OptionalCreateCodeReviewRequestTypeDef
+class CreateCodeReviewRequestRequestTypeDef(
+    _RequiredCreateCodeReviewRequestRequestTypeDef, _OptionalCreateCodeReviewRequestRequestTypeDef
 ):
     pass
 
 
-CreateCodeReviewResponseResponseTypeDef = TypedDict(
-    "CreateCodeReviewResponseResponseTypeDef",
+CreateCodeReviewResponseTypeDef = TypedDict(
+    "CreateCodeReviewResponseTypeDef",
     {
         "CodeReview": "CodeReviewTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeCodeReviewRequestTypeDef = TypedDict(
-    "DescribeCodeReviewRequestTypeDef",
+DescribeCodeReviewRequestRequestTypeDef = TypedDict(
+    "DescribeCodeReviewRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
     },
 )
 
-DescribeCodeReviewResponseResponseTypeDef = TypedDict(
-    "DescribeCodeReviewResponseResponseTypeDef",
+DescribeCodeReviewResponseTypeDef = TypedDict(
+    "DescribeCodeReviewResponseTypeDef",
     {
         "CodeReview": "CodeReviewTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredDescribeRecommendationFeedbackRequestTypeDef = TypedDict(
-    "_RequiredDescribeRecommendationFeedbackRequestTypeDef",
+_RequiredDescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeRecommendationFeedbackRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
         "RecommendationId": str,
     },
 )
-_OptionalDescribeRecommendationFeedbackRequestTypeDef = TypedDict(
-    "_OptionalDescribeRecommendationFeedbackRequestTypeDef",
+_OptionalDescribeRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeRecommendationFeedbackRequestRequestTypeDef",
     {
         "UserId": str,
     },
@@ -287,30 +288,30 @@ _OptionalDescribeRecommendationFeedbackRequestTypeDef = TypedDict(
 )
 
 
-class DescribeRecommendationFeedbackRequestTypeDef(
-    _RequiredDescribeRecommendationFeedbackRequestTypeDef,
-    _OptionalDescribeRecommendationFeedbackRequestTypeDef,
+class DescribeRecommendationFeedbackRequestRequestTypeDef(
+    _RequiredDescribeRecommendationFeedbackRequestRequestTypeDef,
+    _OptionalDescribeRecommendationFeedbackRequestRequestTypeDef,
 ):
     pass
 
 
-DescribeRecommendationFeedbackResponseResponseTypeDef = TypedDict(
-    "DescribeRecommendationFeedbackResponseResponseTypeDef",
+DescribeRecommendationFeedbackResponseTypeDef = TypedDict(
+    "DescribeRecommendationFeedbackResponseTypeDef",
     {
         "RecommendationFeedback": "RecommendationFeedbackTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeRepositoryAssociationRequestTypeDef = TypedDict(
-    "DescribeRepositoryAssociationRequestTypeDef",
+DescribeRepositoryAssociationRequestRequestTypeDef = TypedDict(
+    "DescribeRepositoryAssociationRequestRequestTypeDef",
     {
         "AssociationArn": str,
     },
 )
 
-DescribeRepositoryAssociationResponseResponseTypeDef = TypedDict(
-    "DescribeRepositoryAssociationResponseResponseTypeDef",
+DescribeRepositoryAssociationResponseTypeDef = TypedDict(
+    "DescribeRepositoryAssociationResponseTypeDef",
     {
         "RepositoryAssociation": "RepositoryAssociationTypeDef",
         "Tags": Dict[str, str],
@@ -318,15 +319,15 @@ DescribeRepositoryAssociationResponseResponseTypeDef = TypedDict(
     },
 )
 
-DisassociateRepositoryRequestTypeDef = TypedDict(
-    "DisassociateRepositoryRequestTypeDef",
+DisassociateRepositoryRequestRequestTypeDef = TypedDict(
+    "DisassociateRepositoryRequestRequestTypeDef",
     {
         "AssociationArn": str,
     },
 )
 
-DisassociateRepositoryResponseResponseTypeDef = TypedDict(
-    "DisassociateRepositoryResponseResponseTypeDef",
+DisassociateRepositoryResponseTypeDef = TypedDict(
+    "DisassociateRepositoryResponseTypeDef",
     {
         "RepositoryAssociation": "RepositoryAssociationTypeDef",
         "Tags": Dict[str, str],
@@ -352,14 +353,14 @@ KMSKeyDetailsTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListCodeReviewsRequestTypeDef = TypedDict(
-    "_RequiredListCodeReviewsRequestTypeDef",
+_RequiredListCodeReviewsRequestRequestTypeDef = TypedDict(
+    "_RequiredListCodeReviewsRequestRequestTypeDef",
     {
         "Type": TypeType,
     },
 )
-_OptionalListCodeReviewsRequestTypeDef = TypedDict(
-    "_OptionalListCodeReviewsRequestTypeDef",
+_OptionalListCodeReviewsRequestRequestTypeDef = TypedDict(
+    "_OptionalListCodeReviewsRequestRequestTypeDef",
     {
         "ProviderTypes": List[ProviderTypeType],
         "States": List[JobStateType],
@@ -371,14 +372,14 @@ _OptionalListCodeReviewsRequestTypeDef = TypedDict(
 )
 
 
-class ListCodeReviewsRequestTypeDef(
-    _RequiredListCodeReviewsRequestTypeDef, _OptionalListCodeReviewsRequestTypeDef
+class ListCodeReviewsRequestRequestTypeDef(
+    _RequiredListCodeReviewsRequestRequestTypeDef, _OptionalListCodeReviewsRequestRequestTypeDef
 ):
     pass
 
 
-ListCodeReviewsResponseResponseTypeDef = TypedDict(
-    "ListCodeReviewsResponseResponseTypeDef",
+ListCodeReviewsResponseTypeDef = TypedDict(
+    "ListCodeReviewsResponseTypeDef",
     {
         "CodeReviewSummaries": List["CodeReviewSummaryTypeDef"],
         "NextToken": str,
@@ -386,14 +387,14 @@ ListCodeReviewsResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRecommendationFeedbackRequestTypeDef = TypedDict(
-    "_RequiredListRecommendationFeedbackRequestTypeDef",
+_RequiredListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_RequiredListRecommendationFeedbackRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
     },
 )
-_OptionalListRecommendationFeedbackRequestTypeDef = TypedDict(
-    "_OptionalListRecommendationFeedbackRequestTypeDef",
+_OptionalListRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "_OptionalListRecommendationFeedbackRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -404,15 +405,15 @@ _OptionalListRecommendationFeedbackRequestTypeDef = TypedDict(
 )
 
 
-class ListRecommendationFeedbackRequestTypeDef(
-    _RequiredListRecommendationFeedbackRequestTypeDef,
-    _OptionalListRecommendationFeedbackRequestTypeDef,
+class ListRecommendationFeedbackRequestRequestTypeDef(
+    _RequiredListRecommendationFeedbackRequestRequestTypeDef,
+    _OptionalListRecommendationFeedbackRequestRequestTypeDef,
 ):
     pass
 
 
-ListRecommendationFeedbackResponseResponseTypeDef = TypedDict(
-    "ListRecommendationFeedbackResponseResponseTypeDef",
+ListRecommendationFeedbackResponseTypeDef = TypedDict(
+    "ListRecommendationFeedbackResponseTypeDef",
     {
         "RecommendationFeedbackSummaries": List["RecommendationFeedbackSummaryTypeDef"],
         "NextToken": str,
@@ -420,14 +421,14 @@ ListRecommendationFeedbackResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRecommendationsRequestTypeDef = TypedDict(
-    "_RequiredListRecommendationsRequestTypeDef",
+_RequiredListRecommendationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListRecommendationsRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
     },
 )
-_OptionalListRecommendationsRequestTypeDef = TypedDict(
-    "_OptionalListRecommendationsRequestTypeDef",
+_OptionalListRecommendationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListRecommendationsRequestRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -436,14 +437,15 @@ _OptionalListRecommendationsRequestTypeDef = TypedDict(
 )
 
 
-class ListRecommendationsRequestTypeDef(
-    _RequiredListRecommendationsRequestTypeDef, _OptionalListRecommendationsRequestTypeDef
+class ListRecommendationsRequestRequestTypeDef(
+    _RequiredListRecommendationsRequestRequestTypeDef,
+    _OptionalListRecommendationsRequestRequestTypeDef,
 ):
     pass
 
 
-ListRecommendationsResponseResponseTypeDef = TypedDict(
-    "ListRecommendationsResponseResponseTypeDef",
+ListRecommendationsResponseTypeDef = TypedDict(
+    "ListRecommendationsResponseTypeDef",
     {
         "RecommendationSummaries": List["RecommendationSummaryTypeDef"],
         "NextToken": str,
@@ -451,8 +453,8 @@ ListRecommendationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListRepositoryAssociationsRequestTypeDef = TypedDict(
-    "ListRepositoryAssociationsRequestTypeDef",
+ListRepositoryAssociationsRequestRequestTypeDef = TypedDict(
+    "ListRepositoryAssociationsRequestRequestTypeDef",
     {
         "ProviderTypes": List[ProviderTypeType],
         "States": List[RepositoryAssociationStateType],
@@ -464,8 +466,8 @@ ListRepositoryAssociationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListRepositoryAssociationsResponseResponseTypeDef = TypedDict(
-    "ListRepositoryAssociationsResponseResponseTypeDef",
+ListRepositoryAssociationsResponseTypeDef = TypedDict(
+    "ListRepositoryAssociationsResponseTypeDef",
     {
         "RepositoryAssociationSummaries": List["RepositoryAssociationSummaryTypeDef"],
         "NextToken": str,
@@ -473,15 +475,15 @@ ListRepositoryAssociationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -516,8 +518,8 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-PutRecommendationFeedbackRequestTypeDef = TypedDict(
-    "PutRecommendationFeedbackRequestTypeDef",
+PutRecommendationFeedbackRequestRequestTypeDef = TypedDict(
+    "PutRecommendationFeedbackRequestRequestTypeDef",
     {
         "CodeReviewArn": str,
         "RecommendationId": str,
@@ -694,8 +696,8 @@ SourceCodeTypeTypeDef = TypedDict(
     total=False,
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "Tags": Dict[str, str],
@@ -711,8 +713,8 @@ ThirdPartySourceRepositoryTypeDef = TypedDict(
     },
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "TagKeys": List[str],
